# Remove private provides from .so files in the python_sitearch directory
%global __provides_exclude_from ^%{python_sitearch}/.*\\.so$

Name:           xpra
Version:        0.9.8
Release:        1%{?dist}
Summary:        screen for X

License:        GPLv2+
URL:            https://www.xpra.org/
Source0:        https://xpra.org/src/%{name}-%{version}.tar.xz

# patch setup.py to disable building bundled libraries
Patch1:         %{name}-unbundle-python-rencode.patch
Patch2:         %{name}-unbundle-python-webm.patch

# disable parti; it's going away upstream soon
Patch3:         %{name}-disable-parti.patch

BuildRequires:  python2-devel pygobject2-devel pygtk2-devel
BuildRequires:  libXtst-devel
BuildRequires:  Cython
BuildRequires:  desktop-file-utils

Requires:       python-imaging
Requires:       dbus-python
Requires:       xorg-x11-server-utils xorg-x11-server-Xvfb
Requires:       xorg-x11-drv-dummy xorg-x11-drv-void
Requires:       PyOpenGL pygtkglext
Requires:       python-numeric numpy
Requires:       gstreamer gstreamer-python
Requires:       gstreamer-plugins-base gstreamer-plugins-good
Requires:       pulseaudio pulseaudio-utils
Requires:       python-rencode
Requires:       python-webm

#temporary Obsoletes for the benefit of those installing from the review
#I'll drop these when I import xpra into the distribution proper
Obsoletes:      parti < 0.9.0
Obsoletes:      python-wimpiggy < 0.9.0
Provides:       python-wimpiggy = %{version}-%{release}

%description
Xpra is "screen for X": it allows you to run X programs, usually on a remote
host, direct their display to your local machine, and then to disconnect from
these programs and reconnect from the same or another machine, without losing
any state. It gives you remote access to individual applications.

Xpra is "rootless" or "seamless": programs you run under it show up on your
desktop as regular programs, managed by your regular window manager.
Sessions can be accessed over SSH, or password protected over plain TCP sockets.
Xpra is usable over reasonably slow links and does its best to adapt to changing
network bandwidth constraints.


%prep
%setup -q
%patch3 -p1

#disable codecs thar are forbidden in Fedora
patch -p1 -i patches/disable-x264.patch
patch -p1 -i patches/disable-vpx.patch

#use the system python-rencode
%patch1 -p1
rm -f xpra/rencode/*
echo "from rencode import *" > xpra/rencode/__init__.py
echo "from rencode._rencode import __version__" >> xpra/rencode/__init__.py

#use the system python-webm
%patch2 -p1
rm -f xpra/webm/*
echo "from webm import *" > xpra/webm/__init__.py


%build
CFLAGS="%{optflags}" %{__python} setup.py build


%install
%{__python} setup.py install --skip-build --root %{buildroot}

#move icon to proper directory
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
mv %{buildroot}%{_datadir}/icons/xpra.png \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/

#remove doc stuff from /usr/share
rm -rf \
    %{buildroot}%{_datadir}/parti \
    %{buildroot}%{_datadir}/xpra/xpra.README \
    %{buildroot}%{_datadir}/xpra/COPYING \
    %{buildroot}%{_datadir}/xpra/webm \
    %{buildroot}%{_datadir}/wimpiggy

#drop shebangs from python_sitearch
sed -i '1{\@^#!/usr/bin/env python@d}' \
    %{buildroot}%{python_sitearch}/xpra/sound/sink.py \
    %{buildroot}%{python_sitearch}/xpra/gl/gl_check.py \
    %{buildroot}%{python_sitearch}/xpra/sound/gstreamer_util.py \
    %{buildroot}%{python_sitearch}/xpra/sound/src.py \
    %{buildroot}%{python_sitearch}/xpra/keys.py \
    %{buildroot}%{python_sitearch}/xpra/stats/__init__.py \
    %{buildroot}%{python_sitearch}/xpra/nested_main.py \
    %{buildroot}%{python_sitearch}/xpra/sound/sound_pipeline.py \
    %{buildroot}%{python_sitearch}/xpra/sound/__init__.py \
    %{buildroot}%{python_sitearch}/xpra/platform/graph.py \
    %{buildroot}%{python_sitearch}/xpra/sound/pulseaudio_util.py \
    %{buildroot}%{python_sitearch}/xpra/gtk_view_keyboard.py
    
#fix permissions on shared objects
chmod 0755 \
    %{buildroot}%{python_sitearch}/xpra/wait_for_x_server.so \
    %{buildroot}%{python_sitearch}/xpra/xor/cyxor.so \
    %{buildroot}%{python_sitearch}/xpra/stats/cymaths.so \
    %{buildroot}%{python_sitearch}/wimpiggy/lowlevel/bindings.so \
    %{buildroot}%{python_sitearch}/wimpiggy/gdk/gdk_atoms.so

    
%check
desktop-file-validate %{buildroot}%{_datadir}/applications/xpra_launcher.desktop


%post
/usr/bin/update-desktop-database &> /dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
/usr/bin/update-desktop-database &> /dev/null || :

if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%dir %{_sysconfdir}/xpra
%config(noreplace) %{_sysconfdir}/xpra/xorg.conf
%config(noreplace) %{_sysconfdir}/xpra/xpra.conf
%{_bindir}/xpra
%{_bindir}/xpra_Xdummy
%{_bindir}/xpra_launcher
%{python_sitearch}/xpra
%{python_sitearch}/wimpiggy
%{python_sitearch}/*.egg-info
%{_datadir}/applications/xpra_launcher.desktop
%{_datadir}/icons/hicolor/48x48/apps/xpra.png
%{_mandir}/man1/xpra.1.*
%{_mandir}/man1/xpra_launcher.1.*
%{_datadir}/xpra
%doc xpra.README COPYING wimpiggy.README NEWS


%changelog
* Thu Aug 01 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.8-1
- new upstream release 0.9.8
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-July/000615.html
- use HTTPS for URL and Source0

* Wed Jul 03 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.6-1
- new upstream release 0.9.6
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-June/000552.html

* Thu Jun 27 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.5-1
- new upstream release 0.9.5
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-June/000549.html

* Thu May 30 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.4-1
- new upstream release 0.9.4
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000539.html

* Mon May 13 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.2-1
- new upstream release 0.9.2
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000525.html

* Fri May 10 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.1-1
- new upstream release 0.9.1
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000522.html

* Tue May 07 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.0-2
- fix rencode __version__ importing

* Thu May 02 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.0-1
- new upstream release 0.9.0
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-April/000479.html
- delete the bundled code in prep instead of inside the patches
- don't bother including parti; it's going away upstream soon
- merge python-wimpiggy into main xpra package; it won't be seperated upstream soon

* Thu Apr 18 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-4
- unbundle rencode and webm
- fix equality operator in Requires
- drop unnecessary multiple copies of NEWS
- don't remove buildroot

* Thu Apr 11 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-3
- drop unmet dependency on gstreamer-plugins-ugly
- fix permissions on shared objects
- add scriptlets necessary for icon/desktop file

* Thu Mar 28 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-2
- disable codecs prohibited in Fedora

* Thu Mar 14 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-1
- initial package
